@@ -2,16 +2,16 @@ package Text::Trac::Context;
 use strict;
 use base qw (Class::Accessor::Fast);
 
-__PACKAGE__->mk_accessors( qw( current_ul_level current_ol_level min_heading_level permalink in_block_of ) );
+__PACKAGE__->mk_accessors( qw( ul ol min_heading_level permalink in_block_of ) );
 
 my %Defaults = (
-        text               => '',
-        html               => '',
-        htmllines          => [],
-        current_ul_level   => 0,
-        current_ol_level   => 0,
-        shift_count        => 0,
-        in_block_of        => [],
+        text        => '',
+        html        => '',
+        htmllines   => [],
+        ul          => {},
+        ol          => {},
+        shift_count => 0,
+        in_block_of => [],
 );
 
 sub new {
